{% include "django_recaptcha/includes/js_v3.html" %}
<input
    type="hidden"
    name="{{ widget.name }}"
    {% for name, value in widget.attrs.items %}{% if value is not False %} {{ name }}{% if value is not True %}="{{ value|stringformat:'s' }}"{% endif %}{% endif %}{% endfor %}
>
